@@ -35,7 +35,7 @@ cursor_source_find_image (CursorSource *source,
 {
   GSList *tmp_list;
 
-  for (tmp_list = source->images; tmp_list; tmp_list = tmp_list++)
+  for (tmp_list = source->images; tmp_list; tmp_list = tmp_list->next)
     {
       CursorImage *image = tmp_list->data;
 
@@ -276,9 +276,12 @@ cursor_add_source (Cursor       *cursor,
 
       if (i != 0 && !cursor_is_present (cursor, source, i))
 	{
-	  g_printerr ("Frame %d missing for cursor %s at size %d\n",
+	  g_printerr ("Frame %d missing for cursor '%s' at size %d\n",
 		      i, cursor->name, source->size);
-	  return FALSE;
+	  frame = g_new0 (CursorFrame, 1);
+	  frame->size = -1;
+	  cursor->frames = g_slist_append (cursor->frames, frame);
+	  continue;
 	}
 
       frame = g_new0 (CursorFrame, 1);
@@ -344,7 +347,9 @@ cursor_theme_write_cursor (CursorTheme *theme,
     {
       CursorFrame *frame = tmp_list->data;
       char *filename;
-
+      
+      if (frame->size == -1)
+	  continue;
       filename = g_strdup_printf ("%s-%d.png", cursor->name, i);
       if (gdk_pixbuf_save (frame->image, filename, "png", &error, NULL))
 	{
