@@ -38,14 +38,15 @@ struct {
   PangoLayout *name_layout;
   int bold;
 } credits[] = {
-  
+    /*  
   { "RED HAT LINUX 8.0", "", 0, 0, NULL, NULL, 1 },
   { "", "", 0, 0, NULL, NULL, 0 },
   { "", "", 0, 0, NULL, NULL, 0 },
   { "", "", 0, 0, NULL, NULL, 0 },    
   { "OS DEVELOPMENT", "", 0, 0, NULL, NULL, 1 },
   { "", "", 0, 0, NULL, NULL, 0 },
-  { "Producer", "PRESTON BROWN", 0, 0, NULL, NULL, 0 },
+  { "Producer", "MATT WILSON", 0, 0, NULL, NULL, 0 },
+  { "Associate Producer", "PRESTON BROWN", 0, 0, NULL, NULL, 0 },
   { "Director", "BILL NOTTINGHAM", 0, 0, NULL, NULL, 0 },
   { "Associate Director", "MICHAEL FULBRIGHT", 0, 0, NULL, NULL, 0 },
   { "Cinematographer", "HAVOC PENNINGTON", 0, 0, NULL, NULL, 0 },
@@ -58,27 +59,31 @@ struct {
   { "Standards and Practices", "MATT WILSON", 0, 0, NULL, NULL, 0 },
   { "Kung Fu Choreographer", "THAN NGO", 0, 0, NULL, NULL, 0 },
   { "Bero's Stunt Double", "THOMAS WÖRNER", 0, 0, NULL, NULL, 0 },
-  { "Norwegian Møøse Trainer", "TROND EIVIND GLOMSRØD", 0, 0, NULL, NULL, 0 },
   { "Cultural Attaché", "JONATHAN BLANDFORD", 0, 0, NULL, NULL, 0 },
-  { "Stunt Double", "KARSTEN HOPP", 0, 0, NULL, NULL, 0 },
+  { "Dinosaur Specialist", "KARSTEN HOPP", 0, 0, NULL, NULL, 0 },
   { "Stunt Double", "CHRIS BLIZZARD", 0, 0, NULL, NULL, 0 },
   { "Steadicam Operator", "DAN WALSH", 0, 0, NULL, NULL, 0 },
   { "Miscreant", "TIM WAUGH", 0, 0, NULL, NULL, 0 },
   { "Steely-eyed Linux Man", "OWEN TAYLOR", 0, 0, NULL, NULL, 0 },
   { "Swedish Guy #1", "ALEX LARSSON", 0, 0, NULL, NULL, 0 },
-  { "Moose Trainer", "MARK J. COX", 0, 0, NULL, NULL, 0 },
+  { "Cybermat", "MARK J. COX", 0, 0, NULL, NULL, 0 },
   { "Monkey Handler", "GARY BENSON", 0, 0, NULL, NULL, 0 },
-  { "Funeral Director", "JOE ORTON", 0, 0, NULL, NULL, 0 },
-  { "Animal Wrangler", "PHILIP COPELAND", 0, 0, NULL, NULL, 0 },
-  { "Wardrobe", "ERIK TROAN", 0, 0, NULL, NULL, 0 },
-  { "X-Man", "MIKE HARRIS", 0, 0, NULL, NULL, 0 },
+  { "Undertaker", "JOE ORTON", 0, 0, NULL, NULL, 0 },
+  { "Canadian X Coordinator, eh", "MIKE A. HARRIS", 0, 0, NULL, NULL, 0 },
   { "Simplified Chinese & Asian X11", "YU SHAO", 0, 0, NULL, NULL, 0 },
   { "Traditional Chinese & Asian KDE", "LEON HO", 0, 0, NULL, NULL, 0 },
-  { "Japanese & Asian Compliance", "YUKIHIRO NAKAI", 0, 0, NULL, NULL, 0 },
+  { "Japanese & Compliance", "YUKIHIRO NAKAI", 0, 0, NULL, NULL, 0 },
   { "Japanese & Asian GNOME", "AKIRA TAGOH", 0, 0, NULL, NULL, 0 },
   { "Auto Mechanic", "JENS PETERSEN", 0, 0, NULL, NULL, 0 },
   { "Miracle Worker", "JAKUB JEL\xc3\x8dNEK", 0, 0, NULL, NULL, 0 },
-  { "Free Mason", "DAVE", 0, 0, NULL, NULL, 0 },
+  { "Gaffer", "JOHN DENNIS", 0, 0, NULL, NULL, 0 },
+  { "Samba Dancer", "JAY FENLASON", 0, 0, NULL, NULL, 0 },
+  { "ASCII Evangelist", "ADRIAN HAVILL", 0, 0, NULL, NULL, 0 },
+  { "Screener", "LON HOHBERGER", 0, 0, NULL, NULL, 0 },
+  { "Snake Trainer", "MIHAI IBANESCU", 0, 0, NULL, NULL, 0 },
+  { "Key Grip", "PATRICK MACDONALD", 0, 0, NULL, NULL, 0 },
+  { "Postgre\"Sound\" Generation", "ANDREW OVERHOLT", 0, 0, NULL, NULL, 0 },
+  { "Wardrobe", "CHARLIE BENNETT", 0, 0, NULL, NULL, 0 },
   { "", "", 0, 0, NULL, NULL, 0 },
 
   { "KERNEL DEVELOPMENT", "", 0, 0, NULL, NULL, 1 },
@@ -86,11 +91,12 @@ struct {
   { "Feline Facilitator", "MICHAEL K. JOHNSON", 0, 0, NULL, NULL, 0 },
   { "Kolonel Patch", "ARJAN VAN DE VEN", 0, 0, NULL, NULL, 0 },
   { "Pointer Casting", "ALAN COX", 0, 0, NULL, NULL, 0 },
-  { "Event Co-ordinator", "BEN LaHAISE", 0, 0, NULL, NULL, 0 },
+  { "Remote Location Coordinator", "STEVE DICKSON", 0, 0, NULL, NULL, 0 },
+  { "Second Bandana Guy", "JEFF GARZIK", 0, 0, NULL, NULL, 0 },
+  { "Growling Mad Hacker", "BEN LaHAISE", 0, 0, NULL, NULL, 0 },
   { "Fortune Cookie Stuffer", "DOUG LEDFORD", 0, 0, NULL, NULL, 0 },
-  { "The Teacher", "BOB MATTHEWS", 0, 0, NULL, NULL, 0 },
   { "Networking Entomologist", "DAVID S. MILLER", 0, 0, NULL, NULL, 0 },
-  { "Scheduling", "INGO MOLNAR", 0, 0, NULL, NULL, 0 },
+  { "Tailor", "INGO MOLNAR", 0, 0, NULL, NULL, 0 },
   { "International Man of Mystery", "STEPHEN TWEEDIE", 0, 0, NULL, NULL, 0 },
   { "Negative Dentry", "AL VIRO", 0, 0, NULL, NULL, 0 },
   { "USB Cable Wrangler", "PETE ZAITCEV", 0, 0, NULL, NULL, 0 },
@@ -99,18 +105,21 @@ struct {
   { "TOOLCHAIN DEVELOPMENT", "", 0, 0, NULL, NULL, 1 },
   { "", "", 0, 0, NULL, NULL, 0 },
   { "General Contractor", "KAREN BENNET", 0, 0, NULL, NULL, 0 },
-  { "GCC 3.2 Specialist", "RICHARD HENDERSON", 0, 0, NULL, NULL, 0 },
+  { "GDB Debugging", "JIM BLANDY", 0, 0, NULL, NULL, 0 },
   { "OProfile Wrangler", "WILL COHEN", 0, 0, NULL, NULL, 0 },
-  { "2nd 2nd Assistant Prestidigitator", "ROLAND McGRATH", 0, 0, NULL, NULL, 0 },
+  { "Mr. NPTL", "ULI DREPPER", 0, 0, NULL, NULL, 0 },
   { "Backhoe Operator", "JAKUB JEL\xc3\x8dNEK", 0, 0, NULL, NULL, 0 },
   { "Tools Generalist", "JEFF LAW", 0, 0, NULL, NULL, 0 },
+  { "Midnight Coder", "JEFF JOHNSTON" , 0, 0, NULL, NULL,0},
   { "Foley Artist", "ANDREW HALEY", 0, 0, NULL, NULL, 0 },
   { "Ozzy Fan", "JOHN HEALY", 0, 0, NULL, NULL, 0 },
+  { "RTL Grip", "RICHARD HENDERSON", 0, 0, NULL, NULL, 0 },
+  { "Continuity", "ROLAND McGRATH", 0, 0, NULL, NULL, 0 },
+  { "C++ Specialist", "JASON MERRILL", 0, 0, NULL, NULL, 0 },
   { "Compiler Tricks", "DIEGO NOVILLO", 0, 0, NULL, NULL, 0 },
-  { "GDB Debugging", "JIM BLANDY", 0, 0, NULL, NULL, 0 },
-  { "TLS Provider", "ELENA ZANNONI", 0, 0, NULL, NULL, 0 },
   { "Performance Tuner", "VLADIMIR MAKAROV", 0, 0, NULL, NULL, 0 },
   { "Mr. Java", "TOM TROMEY", 0, 0, NULL, NULL, 0 },
+  { "TLS Provider", "ELENA ZANNONI", 0, 0, NULL, NULL, 0 },
   { "", "", 0, 0, NULL, NULL, 0 },
 
   { "QUALITY ASSURANCE", "", 0, 0, NULL, NULL, 1 },
@@ -121,13 +130,13 @@ struct {
   { "Death, Destroyer of Worlds", "BRIAN BROCK", 0, 0, NULL, NULL, 0 },
   { "Digital Message Therapist", "BEN LEVENSON", 0, 0, NULL, NULL, 0 },
   { "Key Grip", "DAVE LAWRENCE", 0, 0, NULL, NULL, 0 },
-  { "Korean & Asian Testing", "DAVID JOO", 0, 0, NULL, NULL, 0 },
+  { "Korean & Localized Testing", "DAVID JOO", 0, 0, NULL, NULL, 0 },
   { "", "", 0, 0, NULL, NULL, 0 },
 
   { "RELEASE ENGINEERING", "", 0, 0, NULL, NULL, 1 },
   { "", "", 0, 0, NULL, NULL, 0 },
   { "Benevolent Dictator", "TIM POWERS", 0, 0, NULL, NULL, 0 },
-  { "Assistant to Mr. Powers", "JOHN FLANAGAN", 0, 0, NULL, NULL, 0 },
+  { "Mr. Powers' Valet", "JOHN FLANAGAN", 0, 0, NULL, NULL, 0 },
   { "Beekeeper", "ELLIOT LEE", 0, 0, NULL, NULL, 0 },
   { "", "", 0, 0, NULL, NULL, 0 },
 
@@ -147,15 +156,14 @@ struct {
   { "Set Decorators", "THAN NGO", 0, 0, NULL, NULL, 0 },
   { "", "ALEX LARSSON", 0, 0, NULL, NULL, 0 },
   { "", "HAVOC PENNINGTON", 0, 0, NULL, NULL, 0 },
-  { "", "BERNHARD ROSENKRÄNZER", 0, 0, NULL, NULL, 0 },
-  { "", "PRESTON BROWN", 0, 0, NULL, NULL, 0 },
   { "", "JONATHAN BLANDFORD", 0, 0, NULL, NULL, 0 },
   { "", "MATT WILSON", 0, 0, NULL, NULL, 0 },
   { "", "", 0, 0, NULL, NULL, 0 },
 
   { "RED HAT NETWORK", "", 0, 0, NULL, NULL, 1 },
   { "", "", 0, 0, NULL, NULL, 0 },
-  { "Dictator", "CRISTIAN GAFTON", 0, 0, NULL, NULL, 0 },
+  { "Director", "GREG PETERS", 0, 0, NULL, NULL, 0 },
+  { "Good Fellow", "CRISTIAN GAFTON", 0, 0, NULL, NULL, 0 },
   { "Dr. Doom", "ADRIAN LIKINS", 0, 0, NULL, NULL, 0 },
   { "Reverse Engineer", "JEFF JOHNSON", 0, 0, NULL, NULL, 0 },
   { "Prosthetics Technician", "CHIP TURNER", 0, 0, NULL, NULL, 0 },
@@ -167,43 +175,53 @@ struct {
   { "Minion #2", "BRET McMILLAN", 0, 0, NULL, NULL, 0 },
   { "Special Guest Villain", "ROBIN NORWOOD", 0, 0, NULL, NULL, 0 },
   { "Taint Inspector", "JOSEF KOMENDA", 0, 0, NULL, NULL, 0 },
-  { "Political Activist", "BRIAN FAUSTYN", 0, 0, NULL, NULL, 0 },
   { "Paint Technician", "GARRETT LeSAGE", 0, 0, NULL, NULL, 0 },
-  { "Cheetah Tamer", "BARRY DUPLANTIS", 0, 0, NULL, NULL, 0 },
   { "", "", 0, 0, NULL, NULL, 0 },
   
   { "TRANSLATION", "", 0, 0, NULL, NULL, 1 },
   { "", "", 0, 0, NULL, NULL, 0 },
+  { "Flight Controller", "MICHAEL HIDEO", 0, 0, NULL, NULL, 0 },
   { "Simplified Chinese", "SARAH SMITH", 0, 0, NULL, NULL, 0 },
   { "Traditional Chinese", "BEN WU", 0, 0, NULL, NULL, 0 },
   { "Czech", "MILAN KERSLAGER", 0, 0, NULL, NULL, 0 },
+  { "", "MILOSLAV TRMAC", 0, 0, NULL, NULL, 0 },
   { "Danish", "KELD SIMONSEN", 0, 0, NULL, NULL, 0 },
   { "Dutch", "TACO WITTE", 0, 0, NULL, NULL, 0 },
-  { "French", "ARNAUD HERVE", 0, 0, NULL, NULL, 0 },
-  { "", "VÉRONIQUE MICHEL", 0, 0, NULL, NULL, 0 },
-  { "", "EMMANUELLE ROUE", 0, 0, NULL, NULL, 0 },
-  { "", "NATHALIE SCHOLZ", 0, 0, NULL, NULL, 0 },
-  { "French & Italian", "BETTINA DE MONTI", 0, 0, NULL, NULL, 0 },
-  { "Icelandic", "RICHARD ALLEN", 0, 0, NULL, NULL, 0 },
-  { "German", "CLAUDIA KRUG", 0, 0, NULL, NULL, 0 },
+  { "", "GREGORY PETIT", 0, 0, NULL, NULL, 0 },
+  { "", "TINO MEINEN", 0, 0, NULL, NULL, 0 },
+  { "French", "JEAN-PAUL AUBRY", 0, 0, NULL, NULL, 0 },
+  { "", "AUDREY SIMONS", 0, 0, NULL, NULL, 0 },
+  { "Italian", "OLYMPIA AMMENDOLA", 0, 0, NULL, NULL, 0 },
+  { "German", "BERND GROH", 0, 0, NULL, NULL, 0 },
+  { "", "NADINE RICHTER", 0, 0, NULL, NULL, 0 },
   { "Greek", "NIKOS CHARONITAKIS", 0, 0, NULL, NULL, 0 },
+  { "Hungarian", "TAMAS SZANTO", 0, 0, NULL, NULL, 0 },
+  { "Icelandic", "RICHARD ALLEN", 0, 0, NULL, NULL, 0 },
+  { "Italian", "FRANCESCO VALENTE", 0, 0, NULL, NULL, 0 },
+  { "Japanese", "KIYOTO HASHIDA", 0, 0, NULL, NULL, 0 },
+  { "", "NORIKO MIZUMOTO", 0, 0, NULL, NULL, 0 },
   { "Korean", "MICHELLE KIM", 0, 0, NULL, NULL, 0 },
+  { "Malay", "HASBULLAH BIN PIT", 0, 0, NULL, NULL, 0 },
   { "Norwegian", "KJARTAN MARAAS", 0, 0, NULL, NULL, 0 },
+  { "", "TROND VARSLOT", 0, 0, NULL, NULL, 0 },
   { "Portuguese", "PEDRO MORAIS", 0, 0, NULL, NULL, 0 },
+  { "Brazilian Portuguese", "DAVID BARZILAY", 0, 0, NULL, NULL, 0 },
   { "Russian", "LEON KANTER", 0, 0, NULL, NULL, 0 },
-  { "Spanish", "NURIA SORIANO", 0, 0, NULL, NULL, 0 },
-  { "", "LUJÁN FERNÁNDEZ", 0, 0, NULL, NULL, 0 },
+  { "Spanish", "YELITZA LOUZE", 0, 0, NULL, NULL, 0 },
   { "Swedish", "CHRISTIAN ROSE", 0, 0, NULL, NULL, 0 },
+  { "Tamil", "RAMANI ARUNACHALAM", 0, 0, NULL, NULL, 0 },
   { "Turkish", "NILGÜN BELMA BUGÜNER", 0, 0, NULL, NULL, 0 },
-  { "Japanese", "JAMES HASHIDA", 0, 0, NULL, NULL, 0 },
   { "", "", 0, 0, NULL, NULL, 0 },
 
-  { "PRODUCT MANAGEMENT", "", 0, 0, NULL, NULL, 1 },
+  { "PROGRAM MANAGEMENT", "", 0, 0, NULL, NULL, 1 },
   { "", "", 0, 0, NULL, NULL, 0 },
-  { "Choreographer", "SHELLEY BAINTER", 0, 0, NULL, NULL, 0 },
-  { "Post-Production Supervisor", "LEIGH DAY", 0, 0, NULL, NULL, 0 },
-  { "Speaking In Tongues", "PAUL GAMPE", 0, 0, NULL, NULL, 0 },
-  { "Location Manager", "SUE DENHAM", 0, 0, NULL, NULL, 0 },
+  { "Director", "DEB WOODS", 0, 0, NULL, NULL, 0 },
+  { "Political Activist", "BRIAN FAUSTYN", 0, 0, NULL, NULL, 0 },
+  { "Script Supervisor", "SEAN WITTY", 0, 0, NULL, NULL, 0 },
+  { "Stage Manager", "DEBBIE McGRATH", 0, 0, NULL, NULL, 0 },
+  { "Foreign Corespondent", "PAUL GAMPE", 0, 0, NULL, NULL, 0 },
+  { "Location Managers", "SUE DENHAM", 0, 0, NULL, NULL, 0 },
+  { "", "BOB JOHNSON", 0, 0, NULL, NULL, 0 },
   { "", "", 0, 0, NULL, NULL, 0 },
 
   { "PRODUCTION / FINANCE", "", 0, 0, NULL, NULL, 1},
@@ -216,7 +234,6 @@ struct {
   
   { "SPECIAL CONTRIBUTORS", "", 0, 0, NULL, NULL, 1},
   { "", "", 0, 0, NULL, NULL, 0 },
-  { "Himself", "DUMBBOT3", 0, 0, NULL, NULL, 0 },
   { "Crash Test Dummy", "PORKCHOP", 0, 0, NULL, NULL, 0 },
   { "Shover", "KSROBOT", 0, 0, NULL, NULL, 0 },
   { "Pusher", "REROBOT", 0, 0, NULL, NULL, 0 },
@@ -237,6 +254,13 @@ struct {
   { "", "GNU Project", 0, 0, NULL, NULL, 0 },
   { "", "our Beta Testers", 0, 0, NULL, NULL, 0 },
   { "", "the Open Source Community", 0, 0, NULL, NULL, 0 },
+*/
+
+    
+  { "There is no easter egg", "", 0, 0, NULL, NULL, 0 },
+  { "", "", 0, 0, NULL, NULL, 0 },
+  { "", "", 0, 0, NULL, NULL, 0 },
+  { "", "", 0, 0, NULL, NULL, 0 },    
 };
 
 static int n_credits = G_N_ELEMENTS (credits);  
@@ -247,7 +271,7 @@ static GTimeVal start_time;
 static double current_fraction = 0.0;
 
 /* how long it takes for a line to cross the screen */
-static double seconds_to_cross_screen = 3.0;
+static double seconds_to_cross_screen = 10.0;
 
 /* height of one line */
 static int line_height = 0;
